﻿using System.Text.Json;
using WF_WebAdmin.Model;

namespace WF_WebAdmin.Service;

    public class QuoteServiceStub : IQuoteServiceJson
    {
        private readonly string _jsonFilePath;

        public QuoteServiceStub(string filePath)
        {
            _jsonFilePath = Path.Combine(Environment.CurrentDirectory, "wwwroot", filePath);
        }

        public async Task<List<Quote>> GetQuoteJson()
        {
            if (!File.Exists(_jsonFilePath))
            {
                Console.Out.WriteLine($"{_jsonFilePath} not found");
                return new List<Quote>();
            }

            var json = await File.ReadAllTextAsync(_jsonFilePath);
            return JsonSerializer.Deserialize<List<Quote>>(json) ?? new List<Quote>();
        }

        public async Task SaveQuoteJson(List<Quote> quotes)
        {
            var json = JsonSerializer.Serialize(quotes, new JsonSerializerOptions { WriteIndented = true });
            await File.WriteAllTextAsync(_jsonFilePath, json);
        }

        public async Task AddQuoteJson(Quote quote)
        {
            var data = await GetQuoteJson();
            quote.Id = data.Count > 0 ? data.Max(p => p.Id) + 1 : 1;
            data.Add(quote);
            await SaveQuoteJson(data);
        }

        public async Task DeleteQuoteJson(int id)
        {
            var data = await GetQuoteJson();
            var quote = data.FirstOrDefault(p => p.Id == id);
            if (quote != null)
            {
                data.Remove(quote);
                await SaveQuoteJson(data);
            }
        }

        public async Task UpdateQuoteJson(Quote quote)
        {
            
        }

}  
   